<?php

$lan = array(
  'existingusers' => "Usu&aacute;rios Existentes",
  'nonexistingusers' => "Usu&aacute;rios Inexistentes",
  'existcheckintro' => 'P&aacute;gina para verificar a exist&ecirc;ncia de usu&aacute;rios na base de dados',
  'whatistype' => 'Que tipo de informa&ccedil;&atilde;o voc&ecirc; quer verificar',
  "foreignkey" => "Chave Externa",
  "email" => "Email",
  'key' => 'chave',
  'passwd' => 'senha',
  "continue" => "Continuar",
  "pastevalues" => "Cole nesta caixa os valores a serem verificados, um por linha",
);

?>
